==> eclipse-mylyn_3.6.5+dfsg1.orig.tar.bz2: eclipse-mylyn-3.6.5/org.eclipse.mylyn.tasks/org.eclipse.mylyn.tasks.ui/src/org/eclipse/mylyn/internal/tasks/ui/commands/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2010 Tasktop Technologies and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Tasktop Technologies - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.tasks.ui.commands;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.mylyn.internal.tasks.ui.commands.messages"; //$NON-NLS-1$

	static {
		// load message values from bundle file
		reloadMessages();
	}

	public static void reloadMessages() {
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	public static String AddTaskRepositoryHandler_Add_Task_Repository;

	public static String NewLocalTaskHandler_Could_not_create_local_task;

	public static String OpenTaskAttachmentHandler_failedToOpenViewer;

	public static String OpenTaskAttachmentHandler_noAttachmentViewerFound;

	public static String RemoteTaskSelectionDialog_Add_;

	public static String RemoteTaskSelectionDialog_Add_to_Task_List_category;

	public static String RemoteTaskSelectionDialog_Enter_Key_ID__use_comma_for_multiple_;

	public static String RemoteTaskSelectionDialog_Enter_a_valid_task_ID;

	public static String RemoteTaskSelectionDialog_Matching_tasks;

	public static String RemoteTaskSelectionDialog_Select_a_task_or_repository;

	public static String RemoteTaskSelectionDialog_Select_a_task_repository;
}

==> eclipse-mylyn_3.8.0.orig.tar.bz2: eclipse-mylyn-3.8.0/org.eclipse.mylyn.tasks/org.eclipse.mylyn.tasks.ui/src/org/eclipse/mylyn/internal/tasks/ui/commands/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2010 Tasktop Technologies and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Tasktop Technologies - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.tasks.ui.commands;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.mylyn.internal.tasks.ui.commands.messages"; //$NON-NLS-1$

	static {
		// load message values from bundle file
		reloadMessages();
	}

	public static void reloadMessages() {
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	public static String NewLocalTaskHandler_Could_not_create_local_task;

	public static String OpenTaskAttachmentHandler_failedToOpenViewer;

	public static String OpenTaskAttachmentHandler_noAttachmentViewerFound;

	public static String RemoteTaskSelectionDialog_Add_;

	public static String RemoteTaskSelectionDialog_Add_to_Task_List_category;

	public static String RemoteTaskSelectionDialog_Enter_Key_ID__use_comma_for_multiple_;

	public static String RemoteTaskSelectionDialog_Enter_a_valid_task_ID;

	public static String RemoteTaskSelectionDialog_Matching_tasks;

	public static String RemoteTaskSelectionDialog_Select_a_task_or_repository;

	public static String RemoteTaskSelectionDialog_Select_a_task_repository;

	public static String ShowTasksConnectorDiscoveryWizardCommandHandler_Install_Connectors;

	public static String ShowTasksConnectorDiscoveryWizardCommandHandler_Notify_when_updates_are_available_Text;

	public static String ShowTasksConnectorDiscoveryWizardCommandHandler_Unable_to_launch_connector_install;
}
